"""A simple setup file for the 'HEAVY' test package."""

from setuptools import setup

setup(
    name="pypiserver_mypkg_heavy",
    description="Heavy test pkg",
    version="1.0.0",
    packages=["mypkg_heavy"],
)



"""
This imitates a a heavy package.

- The ~1.4MB `generated_placehoder.py` is generated using the root `Makefile`.
"""


def pkg_name() -> None:
    """Print the package name."""
    print("mypkg_heavy")
